=== modified file 'bzrlib/tests/HTTPTestUtil.py'
--- bzrlib/tests/HTTPTestUtil.py	2006-12-11 13:24:55 +0000
+++ bzrlib/tests/HTTPTestUtil.py	2006-12-12 12:49:55 +0000
@@ -195,12 +195,6 @@
         if self.__secondary_server is None:
             self.__secondary_server = self.create_transport_secondary_server()
             self.__secondary_server.setUp()
-            # Note that addCleanup ensures that last added
-            # callables are called first. That will ensures that
-            # our cleanup is called before the other http server
-            # cleanup if we are created last and our cleanup is
-            # called after the other http server cleanup if we
-            # are created first.
             self.addCleanup(self.__secondary_server.tearDown)
         return self.__secondary_server
 

=== modified file 'bzrlib/tests/HttpServer.py'
--- bzrlib/tests/HttpServer.py	2006-12-11 13:24:55 +0000
+++ bzrlib/tests/HttpServer.py	2006-12-12 12:49:55 +0000
@@ -270,8 +270,6 @@
         else:
             remote_path = '/'.join(path_parts)
 
-        self._http_starting.acquire()
-        self._http_starting.release()
         return self._http_base_url + remote_path
 
     def log(self, format, *args):
@@ -288,30 +286,16 @@
         self._http_base_url = None
         self._http_thread = threading.Thread(target=self._http_start)
         self._http_thread.setDaemon(True)
-        # Ensure we are not influenced by the environment
-        self._http_proxy = os.environ.get("http_proxy")
-        if self._http_proxy is not None:
-            del os.environ["http_proxy"]
-        self._no_proxy = os.environ.get("no_proxy")
-        if self._no_proxy is not None:
-            del os.environ["no_proxy"]
         self._http_thread.start()
+        # Wait for the server thread to start (i.e release the lock)
+        self._http_starting.acquire()
+        self._http_starting.release()
         self.logs = []
 
     def tearDown(self):
         """See bzrlib.transport.Server.tearDown."""
         self._http_running = False
         self._http_thread.join()
-        if self._http_proxy is None:
-            if os.environ.get("http_proxy") is not None:
-                del os.environ["http_proxy"]
-        else:
-            os.environ["http_proxy"] = self._http_proxy
-        if self._no_proxy is None:
-            if os.environ.get("no_proxy") is not None:
-                del os.environ["no_proxy"]
-        else:
-            os.environ["no_proxy"] = self.no_proxy
 
     def get_url(self):
         """See bzrlib.transport.Server.get_url."""

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2006-11-21 01:08:52 +0000
+++ bzrlib/tests/__init__.py	2006-12-12 12:49:55 +0000
@@ -792,6 +792,20 @@
             'BZREMAIL': None, # may still be present in the environment
             'EMAIL': None,
             'BZR_PROGRESS_BAR': None,
+            # Proxies
+            'http_proxy': None,
+            'HTTP_PROXY': None,
+            'https_proxy': None,
+            'HTTPS_PROXY': None,
+            'no_proxy': None,
+            'NO_PROXY': None,
+            'all_proxy': None,
+            'ALL_PROXY': None,
+            # Nobody cares about these ones AFAIK. So far at
+            # least. If you do (care), please update this comment
+            # -- vila 20061212
+            'ftp_proxy': None,
+            'FTP_PROXY': None,
         }
         self.__old_env = {}
         self.addCleanup(self._restoreEnvironment)

=== modified file 'bzrlib/tests/test_http.py'
--- bzrlib/tests/test_http.py	2006-12-11 13:24:55 +0000
+++ bzrlib/tests/test_http.py	2006-12-12 12:49:55 +0000
@@ -632,27 +632,27 @@
     We can't inherit directly from TestCaseWithTwoWebservers or
     the test framework will try to create an instance which
     cannot run, its implementation being incomplete.
+
+    Be aware that we do not setup a real proxy here. Instead, we
+    check that the *conention* goes through the proxy by serving
+    different content (the faked proxy server append '-proxied'
+    to the file names).
     """
 
+    # FIXME: We don't have an https server available, so we don't
+    # test https connections.
+
     def setUp(self):
         TestCaseWithTwoWebservers.setUp(self)
         self.build_tree_contents([('foo', 'contents of foo\n'),
                                   ('foo-proxied', 'proxied contents of foo\n')])
-        # Create the server now. Otherwise, it will created when
-        # test methods are invoked. At that point the test
-        # methods may have set env vars and the HttpServer
-        # creation will erase them.
-        server = self.get_readonly_server()
+        # Let's setup some attributes for tests
+        self.server = self.get_readonly_server()
+        self.no_proxy_host = 'localhost:%d' % self.server.port
         # The secondary server is the proxy
-
-        # NOTE: We do not setup a real proxy, instead we check
-        # that the connection goes thru the proxy by serving
-        # different content
-        proxy = self.get_secondary_server()
-        proxy_url = proxy.get_url()
-        # All tests will rely on the secondary server being set
-        # as the proxy
-        os.environ['http_proxy'] = proxy_url
+        self.proxy = self.get_secondary_server()
+        self.proxy_url = self.proxy.get_url()
+        self._old_env = {}
 
     def create_transport_secondary_server(self):
         """Creates an http server that will serve files with
@@ -660,23 +660,63 @@
         """
         return HttpServer(FakeProxyRequestHandler)
 
+    def _set_and_capture_env_var(self, name, new_value):
+        """Set an environment variable, and reset it when finished."""
+        self._old_env[name] = osutils.set_or_unset_env(name, new_value)
+
+    def _install_env(self, env):
+        for name, value in env.iteritems():
+            self._set_and_capture_env_var(name, value)
+
+    def _restore_env(self):
+        for name, value in self._old_env.iteritems():
+            osutils.set_or_unset_env(name, value)
+
+    def proxied_in_env(self, env):
+        self._install_env(env)
+        url = self.server.get_url()
+        t = self._transport(url)
+        try:
+            self.assertEqual(t.get('foo').read(), 'proxied contents of foo\n')
+        finally:
+            self._restore_env()
+
+    def not_proxied_in_env(self, env):
+        self._install_env(env)
+        url = self.server.get_url()
+        t = self._transport(url)
+        try:
+            self.assertEqual(t.get('foo').read(), 'contents of foo\n')
+        finally:
+            self._restore_env()
+
     def test_http_proxy(self):
-        server = self.get_readonly_server()
-        url = server.get_url()
-        t = self._transport(url)
-        self.assertEqual(t.get('foo').read(),
-                         'proxied contents of foo\n')
-
-    def test_http_no_proxy(self):
-        server = self.get_readonly_server()
-        url = server.get_url()
-        os.environ['no_proxy'] = 'localhost:%d' % server.port
-        t = self._transport(url)
-        try:
-            self.assertEqual(t.get('foo').read(),
-                             'contents of foo\n')
-        finally:
-            del os.environ['no_proxy']
+        self.proxied_in_env({'http_proxy': self.proxy_url})
+
+    def test_HTTP_PROXY(self):
+        self.proxied_in_env({'HTTP_PROXY': self.proxy_url})
+
+    def test_all_proxy(self):
+        self.proxied_in_env({'all_proxy': self.proxy_url})
+
+    def test_ALL_PROXY(self):
+        self.proxied_in_env({'ALL_PROXY': self.proxy_url})
+
+    def test_http_proxy_with_no_proxy(self):
+        self.not_proxied_in_env({'http_proxy': self.proxy_url,
+                                 'no_proxy': self.no_proxy_host})
+
+    def test_HTTP_PROXY_with_NO_PROXY(self):
+        self.not_proxied_in_env({'HTTP_PROXY': self.proxy_url,
+                                 'NO_PROXY': self.no_proxy_host})
+
+    def test_all_proxy_with_no_proxy(self):
+        self.not_proxied_in_env({'all_proxy': self.proxy_url,
+                                 'no_proxy': self.no_proxy_host})
+
+    def test_ALL_PROXY_with_NO_PROXY(self):
+        self.not_proxied_in_env({'ALL_PROXY': self.proxy_url,
+                                 'NO_PROXY': self.no_proxy_host})
 
 
 class TestProxyHttpServer_urllib(TestProxyHttpServer,
@@ -691,15 +731,17 @@
                                  TestCaseWithTwoWebservers):
     """Tests proxy server for pycurl implementation"""
 
-    def test_http_no_proxy(self):
-        server = self.get_readonly_server()
-        url = server.get_url()
-        # Oh my ! pycurl do not check the port part :-( So we
-        # just test the host part
-        os.environ['no_proxy'] = 'localhost'
-        t = self._transport(url)
-        try:
-            self.assertEqual(t.get('foo').read(),
-                             'contents of foo\n')
-        finally:
-            del os.environ['no_proxy']
+    def setUp(self):
+        TestProxyHttpServer.setUp(self)
+        # Oh my ! pycurl does not check for the port as part of
+        # no_proxy :-( So we just test the host part
+        self.no_proxy_host = 'localhost'
+
+    def test_HTTP_PROXY(self):
+        # pycurl do not check HTTP_PROXY for security reasons
+        # (for use in a CGI context that we do not care
+        # about. Should we ?)
+        raise TestSkipped()
+
+    def test_HTTP_PROXY_with_NO_PROXY(self):
+        raise TestSkipped()

=== modified file 'bzrlib/transport/http/_urllib2_wrappers.py'
--- bzrlib/transport/http/_urllib2_wrappers.py	2006-12-11 13:24:55 +0000
+++ bzrlib/transport/http/_urllib2_wrappers.py	2006-12-12 12:49:55 +0000
@@ -638,8 +638,8 @@
             delattr(self, '%s_open' % type)
 
         # We are interested only by the http[s] proxies
-        http_proxy = self.get_proxy('http')
-        https_proxy = self.get_proxy('https')
+        http_proxy = self.get_proxy_env_var('http')
+        https_proxy = self.get_proxy_env_var('https')
 
         if http_proxy is not None:
             if self._debuglevel > 0:
@@ -653,16 +653,27 @@
             setattr(self, 'https_request',
                     lambda request: self.set_proxy(request, 'https'))
 
-    def get_proxy(self, name, default=None):
-        """Get a proxy env var. Returns default if not defined."""
+    def get_proxy_env_var(self, name, default_to='all'):
+        """Get a proxy env var.
+
+        Note that we indirectly relies on
+        urllib.getproxies_environment taking into account the
+        uppercased values for proxy variables.
+        """
         try:
             return self.proxies[name.lower()]
         except KeyError:
-            return default
+            if default_to is not None:
+                # Try to get the alternate environment variable
+                try:
+                    return self.proxies[default_to]
+                except KeyError:
+                    pass
+        return None
 
     def proxy_bypass(self, host):
         """Check if host should be proxied or not"""
-        no_proxy = self.get_proxy('no')
+        no_proxy = self.get_proxy_env_var('no', None)
         if no_proxy is None:
             return False
         hhost, hport = urllib.splitport(host)
@@ -687,7 +698,7 @@
         if self.proxy_bypass(request.get_host()):
             return request
 
-        proxy = self.get_proxy(type)
+        proxy = self.get_proxy_env_var(type)
         if self._debuglevel > 0:
             print 'set_proxy %s_request for %r' % (type, proxy)
         orig_type = request.get_type()

